"""
:authors: PavukEdya, Sou1Guard
:license: Apache License, Version 2.0, see LICENSE file

:copyright: (c) 2023 PavukEdya, Sou1Guard
"""


import os
from skimage.metrics import structural_similarity
import numpy as np
import cv2


def get_median_frame(video_name, save_path):
    cap = cv2.VideoCapture(video_name)
    frame_ids = cap.get(cv2.CAP_PROP_FRAME_COUNT) * np.random.uniform(size=40)
    frames = []
    for fid in frame_ids:
        cap.set(cv2.CAP_PROP_POS_FRAMES, fid)
        ret, frame = cap.read()
        frames.append(frame)
    median_frame = np.median(frames, axis=0).astype(dtype=np.uint8)
    filename = os.path.join(save_path, 'median_frame.png')
    cv2.imwrite(filename,median_frame)


def check_differences(image1, image2, accuracy=0.85):
    gray_image1 = cv2.imread(image1, cv2.IMREAD_GRAYSCALE)
    gray_image2 = cv2.imread(image2, cv2.IMREAD_GRAYSCALE)
    (score, diff) = structural_similarity(gray_image1, gray_image2, full=True)
    return True if score < accuracy else False


print(check_differences('median_frame.png', 'test2.png'))



"""
:authors: PavukEdya, Sou1Guard
:license: Apache License, Version 2.0, see LICENSE file

:copyright: (c) 2023 PavukEdya, Sou1Guard
"""

from imagesim import get_median_frame, check_differences

__author__ = 'PavukEdya'
__version__ = '1.0.0'
__email__ = 'slaefir@mail.ru'



#!/usr/bin/env python

from io import open
from setuptools import setup

"""
:authors: PavukEdya, Sou1Guard
:license: Apache License, Version 2.0, see LICENSE file
:copyright: (c) 2023 PavukEdya, Sou1Guard
"""

version = '1.0.0'

# with open('README.md', encoding='utf-8') as f:
#     long_description = f.read()

setup(
    name='imagesim',
    version=version,

    author='PavukEdya',
    author_email='slaefir@mail.ru',

    description=(
        u'Python module for get different between two images'
    ),
    long_description='asd',
    long_description_content_type='text/markdown',

    url='https://github.com/PavukEdya',
    download_url='https://github.com/PavukEdya',

    license='Apache License, Version 2.0, see LICENSE file',

    packages=['imagesim'],
    install_requires=['numpy', 'scikit-image', 'opencv-python'],

    classifiers=[
        'License :: OSI Approved :: Apache Software License',
        'Operating System :: OS Independent',
        'Intended Audience :: End Users/Desktop',
        'Intended Audience :: Developers',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: Implementation :: PyPy',
        'Programming Language :: Python :: Implementation :: CPython',
        ]
    )
